
# q-expansion of newform 50.28.a.d, downloaded from the LMFDB on 10 February 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 50
weight = 28
poly_data = [-3232, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0], 1], [[-7560, 15120], 1]]

hecke_ring_character_values = None
aps_data = [[8192, 0], [1122822, -3], [0, 0], [60098366146, 328021], [3556061366352, 9910802], [161557495177702, -69104516], [5974890860397126, -25951879996], [-155400313093767100, 178199405728], [603996411289278822, -480643559353], [-42544813538331862290, -26375499562424], [-84945813152457240028, 151246394555194], [-500843712938009266154, -2340689760352536], [3414854262916059500022, -3188477033081004], [-7665955110869687564018, 10334866995211141], [-22327303979091754613814, -30857138388965339], [-129675485033940313717698, 139507453753731364], [1041046721310650511584820, 66558695927695972], [338962884768167123159642, 755996758226757408], [-1226808776168474071695014, -8040424768977143577], [-11945096792054066045114388, -2165683630819886502], [6959710353068443272073102, 18373728262091016804], [-26829663635490552331525960, 34183342694187473628], [-2878285630507217730951858, 115956425266729674905], [87219063705643704610172010, 275877327723210960840], [10866033592144670083647646, -584757088444947866740], [707421773806297507182208542, 1644594216101108621336], [-271363639547756182942180658, 275222234847485752515], [-3895067663027550388629008574, -1110520767323685990817], [1988060076557622927142777850, -4361255987280413894056], [-4652632895451585740192834778, 1322049735123076279832], [-23263772178170424476889666254, 16855667993148831988713], [11579808437493456710116917552, -52847187980439398994674], [-88050486117871882179162170274, -16091691418617323799984], [34347387185898811022326428740, -91838402341335495073668], [-157594666551341822538086517150, 118327363926146256257880], [56280649981809042257154784652, -377467094112252979437030], [102673781296698236439480006046, -73327630594990959541064], [45568010561988234223685686942, 788361621017051166467945], [633491283942507241549269379986, -624646454094714649901227], [451204320792464283458279530542, 177482583815752416193960], [-326146393211112607432680625620, -3291341849065430169585956], [-496292573560565007236308648978, -2232791425130331185566736], [4616937197306156225551163943852, -3931597627014961901967002], [-6800567708015557823687505078458, -3199058034124989565002780], [663099421568142552978231041766, 5062235145698000481094708], [5602591341533260495776685596440, 12614384171591116486840496], [13601385022781372423382767579072, -32143880795244754840920370], [27062591774595572457898723829062, -53526877579805031136507597], [10639378289415932629394739867186, -42929781658407320511653901], [-67310682584629714390538613422650, -57890723086644010692563168], [-93617537168215187173714361031018, 53736529018933089693729036], [-78163106521569723346403185738920, 39119380950950074381713068], [-41540836602491996115560630953618, 236894149751220975747838180], [-6830324635732149066756356769648, 84144842091751830263012330], [-242806874398507624517718552685434, -154947382364933752236521896], [-454639074486891759878972912488338, 357728510194545604682391643], [-819901380800000117949906394150710, -321956318275847146612308496], [69090602922862495696804607213132, -1007902706798162915997295434], [725024889963033161458244391965566, 758936254236729377985085256], [559648159609267859839667082770262, 1615723922586051454184254940], [-616433605242838699923099890603738, -1695429426398958280070936887], [-1769244338193403971028073695605258, 171916384469591687585856720], [-2219821399178441100196430992570694, -2401955119099726184344918305], [2621184727893211749094309723664532, -867616330314301546631191106], [-8719032861552040048749771792859418, 1165946183035460946767203256], [-2011825457455486911802544369282514, 2696978226689879882436818188], [-3418961462499351366742495005227608, -8694751999409661326317527738], [15856424601364930423667897076816286, 6529070437741398667056194120], [-7502974029850547921579543070690774, -24890248574390240188485216693], [-8873992350380449689923941265828770, 4916858865596830182007189392], [21636336627869819133948766028833902, 2120926667204714162853305784], [10368750438688376110384410785505480, 12594863122112115734775971696], [-54235913515460469381922703194520774, 2874241871302104952807787349], [30154208669045725090899942637460542, -65292081950054232067668115240], [63561038843662284166241579667992060, -691179606036505643176028624], [69254375124151395979832184566476182, -17131111467451104909024163429], [61418095245619465510077528215529090, 62816791691708941748959875952], [42907599441201167231378008535050726, 15843367521118040630951899772], [-50377146974280779812148215930202238, 54051789562652028294385145184], [20265168911513340272837686973488430, -52770886210188953479314374564], [420413662389362960948146611989107260, -15768633275938138587956133188], [-233722418276324324207880235419608158, -1681737831014287087308056040], [526692161217277020645089530734606012, 78178965369502739441670228510], [373291736801037856386038166465360382, 160440799080567398480075873356], [280370617558552701379989125162629400, 398099720977952586573006211536], [-419227303717369017350552948067028098, -431183910337548628903665782251], [594848310006598195374813752721435270, 276663405119643626233849988948], [812976439498110836904833544885490006, -524872981122454701576953360640], [198374778782931797350190190151852422, -733858690691489820215240933640], [972544437591688857368491412937712702, -463201335900013408248364874961], [-542647478610459422689089146701581414, -391622935245919091436094392897], [-172862033185236897584282589916259880, -1339697945334329249488642395860], [-1484332962923157804406160582317962854, -1503316553174018450084922174191], [3597189813455908593750479297197774992, 275535078376964250340128037274], [-2352870864392077502416304640470555260, 2577267088997120863512089082456], [-4029488464339770586777741303134031218, -667837560646713054064211420149], [-229516481304388442485646611094652690, 1471217618723049385446838957248], [1005390519082681084059209803788424842, 5565284073638617416983713451520], [-549639280711234844957042388954770618, 7383060374314518455816653119681], [-450193068395835496989204396703915498, 1053806248181021010044624794088], [-34703186978614795639127022016258094, -8509542899971914642052939716861], [-5879951971311514085146066242591546714, 19828491188724567511006193302872], [10657042476227764894637884483310730582, 980038533790773656184924222061], [13290432628971475538293722920740897710, -10633978742614018967657053635508], [5014628894444839404344535795877418792, 5915913977820359642028857863430], [-276318399600789227085676137028921514, 15593657548594355328497687191344], [-10973387593609033294294869692119320894, 1339469591458874222247528417663], [8624677956964441459421118424494551502, 2376206531465403636640640605984], [14502490428850910122040997104047371360, -1177714659261805840668943770996], [20434927339467198670288400154192205382, 17240865332512694414979124127372], [-11044041433045562086966551969816722534, -15528058366870862763172574385531], [3394567919013797944899035601707719222, 61466678613216077729050194742572], [-31321067319504642482592021896875008234, -19408523083526934331103255272740], [-18046266778407254754141107031615476020, 47157392051429898212079678084120], [-49156884580274189016031136773058524228, -62429402098241202007542829211726], [-37302632041983831497158227443671454418, 121013652833927075882707534477380], [38198984375631212432034079340971608982, -10379885129737456438275035611419], [53106443338500039254120646396667566186, 18403766439746870827569203234921], [3401775197432941629727806553046523102, 65882198281927263812303784296804], [63511159134405108481586849193219114300, -110603263682885749195951096841276], [66561603718416561369972203399102396882, -143979230081626126847861000873616], [-16560665738758860778734176726191036658, -311291677193069120174915536771020], [123273706352454355670737155954728761446, -163414279101503786095248537727012], [111585449901845201688315069870057329262, -45807069905552548592564121466747], [43296266107699791539386840398614092232, 43805248245689380543717151967090], [-70634365035526580952745848646124186118, 144853797435837428199709469719832], [127029058755020297941607624570857809110, -225045920297224334987375679820472], [-431712862226143632231423393916671054120, 251376556723129417271988592033500], [-378972242034186294841322001256305961934, -407523085626763957773538882247499], [-577453561632486659253864842473415522978, -320800281988955276120261046208128], [-6749988338208778072521464805552952180, 83990576455949936218946289575604], [-179442704539928272240549066751462460858, 436222202432213653583417916080775], [815014790113612456771536976297720360292, 101319199991883100232788300235466], [-420319391267477814419126293744212223634, -409497751336720186603154614484016], [-609739506447041101895096575109155101798, -1436720347645811758188605879648], [-261059655552445103851476435142321801150, -566023152382636334728902040908472], [149874239619294134778355161075269261142, -1727155363122162955773995897602300], [-53838024617548138417018447180658156174, 243179555090770400191358802982491], [1649796573833084007294856525472049478206, -528179928450485099161431923755196], [224699538245124060275923596353103569610, -3462823566213549411759329034312192], [-1126431776182851687923434564083676798048, -2081869810683071993228817799744838], [-1689363379540416669023796124914590017998, 2262018048016848402310974645765224], [-515378739335293335853339183071426292538, 3119001469217931349486137890735143], [707866858675413848622616183158699334506, -2498182266344044011452926875414533], [2745136936193522060627133075083547753050, 439964502270879193231614866636352], [4055540288389737578746431013479164324880, 2049343184818852543808546125943988], [384334307580805526496328740201253846822, 1749771538312602030627339772121172], [-184289599731809448234286995973950527874, 5101402479563956973045431537637608], [5376675725034704414911527854420028184580, 2191932220931457010991969344084476], [-4448324049159236115344210367217225704618, 4011873929612836573469341718101331], [3378193183812929479800003658152061992526, 1187581834863334941077643243097360], [1157636469003296038892607079481246290062, -3922776824981761856876963137926180], [4745449339024112663164518929831078586742, -5874308587214957255991233052198355], [3113009294374148307726635970429265140786, -7192637099762104670164767623343835], [-3503426134555896352970602866391805082374, 11861698333077681169669183141402923], [-2999468669014690222937326137807916341228, 875540872212024037388780774040570], [-3646168436031454659895048457395022312080, -15674061504164453240093040228860364], [3577775344317275018529624103324986338070, 7729432864666707796763707190908180], [-7497716605553409841610937162939472937114, -2615050446714469697591946708607820], [3448738533126971017700290915975627435542, -1021146690122766131024630306287616], [-359796554125117391434412143543137374454, 1840947677074981878887942914825015], [-19463303801602374321734377201623291984618, 13733304638387037021095556677898176], [-4067917420085327854519820413861515474134, 4762252531322513917750275768889425], [5403114064209072368046775830836373208392, 36062615784763328364908806804328230], [2108429150431282617760600428380336697966, -13079023449661641797795637947367084], [-3265357123701375228585178774364898180018, 16699373781339529264521177358738211], [18747385610588830234515330686137807436132, 29959036672990518145586079246384690], [-2112541290810683371628172998783335683074, -25605469765859250401958522750862068], [771303893791769349564437970896737128530, 16472413884659365013404910430042456], [-4218446509194015284064091587572923669818, -52288639385386726007994630391188484], [-8302756380367156992176084882368877984580, -8865670955573448764523026973433424], [60071873450702136569046071162817534684182, 8650644127129435230965650799402016], [-512555912663340554065225467954611412588, -62728208056229086839655162475668810], [-11757085998997101295293426855475333058738, 28126269334173667903788655629954988], [52776601826701282047501113028966138914000, 10859755705594203022634379404087456], [-9170186831159283058700843004053770704870, 94897394114477752571404075453392952], [47203850342927101548951259566774094936232, 48420357292455457377385951384358182], [-30371727840906767016030172374142159773618, -108813822618799699706353055346498656], [67036085902439183849740300174550043083062, -39051470482864654021358847591724217], [21764115953498478787222038523400169215690, -50518853149094173488364473879656896], [-3659057590286062112332797407338516772774, -129429196444721191861320629991737779], [-153088029119384650409183470161741443629248, -28822158922490276303280283524412442], [20839605269299633133671874732201572429102, 205240538933715494020818878540439324], [102622379859916560704565917493868711602606, 69884763041187130817990568725330564], [132999528384443268595736861138916417216582, -49675506369713066787424826897422909], [-92206213886705024311873338955887307168650, -34410186990919158805726868989327496], [41339814805925860867103934097694618145046, 221820794251839430099568934728986632], [-75551803217826438373323703244288884516778, 63106577770816554388763710836845477], [68962648460096794497505726991421369431150, 169747987676675319138319648618503052], [28173158313817687878070038134187229200852, -100666696092020823270645885293628790], [28779964732342940206522485627038847537622, 72730500701165435315356418406467312], [-278361392350147955168203983793453976484018, -158410630579320890113177168381944619], [101062835317048289331234958344404953251512, 10478799583946413614796382966331098], [-392926433685832604406114191974148486082438, -144507566531944023486201382186418640], [361400766040615566879466703830599640643826, -140331145352299706284981060853591229], [-189938138805204911253130926971549273131818, 59223685742529081863592243620074756], [-34214929386329295847435194324564953185618, -404766191357363541474951154480496148], [-182203643347407824290048439296213050437618, -664794037367570861001886564905217284], [81624238169284218570792975691277330898846, 667860325055343706218211514628242432], [-394976527275459318187748943523997373825378, 335366138834698752483807104433726427], [-776287741527919450911785789092373878369650, 11358261427124679957696105466742392], [10888442415666929176943567594167006086332, 42932665873475973618069687333640998], [-82903884316281630025907904899946994651634, 34075991213773432042197960940307532], [-266984858500385257825454361338364449246830, 247622064769288462369687555902925248], [-430047164224533505169518627614388490749500, 533793862421798783389826816608740084], [-434953870011407483170868640027719704034994, -356535271125550292823363366388810768], [-1023921802612166042386544935114476091980640, -217040190467746332299586656442899384], [-1139815199336011369116563283792118354726938, -205120683705515137532038917576312227], [893076586922499070205641929908756026969290, -1066788591940320321532988144067922968], [-199801965923519547383088886234808126200648, 684513562750807860224418999968653438], [-316717650676260765483797607351182197129754, 492654186708843955608665014602197180], [351424915690871924477795714961207760807122, 508254922917181652737515724757979128], [318047747752498410957738010038729535254382, -580914325859966188481092153906901469], [-317250015114463077499030257060241121560734, 1978094808005119286415931838817333879], [261143943526253835828831457119460783888080, 1917688642736958481314150173569464620], [-480261579885331633604267520551308608803098, -1726269588917752915821718059692730156], [1726084239609922859466299609516440706942146, 1099585854793222588811215210207139833], [1657127523139269223593757466270890261582002, 1747264505569624744050351149805891232], [1066260031687572288259035434986273733175666, -433932847919259465653418454661830915], [-2852444420187801620622066573658530820783818, -701265026549436993149178079158938844], [326576444438693936946965636471486450748002, 5099860208965151133275502275435325136], [862000202544187280959886800731542509399040, 2477967922783705088167711316399893236], [1097234451839671974948297787750310030091090, 658411944656698345072404805696030760], [5151253682069005022123387065170984069834382, 210364439844137302868794148890156911], [-691996739512482345437947140187415560005534, -4364953102398470187518745357156453789], [-26364982186087811314662103640672060532910, -6537621742266220808531831817533911552], [1276520097051866102447266566697797232846542, 52546393985213080897719412459767420], [-5862255729121942993765529947728547817469120, 866880284486341455070554369412265208], [-7749524239547575117892322485213670871574, -5646240934566977312186387834359824223], [-2159217314618221857180824101869415337318328, -1365066831105684564104765856595877642], [4647783058753877909161444853644397457124822, 3315722446633899502962134042155346212], [529171226437512256187787906841736147167220, 6947668959662069676933679391225654832], [2963444834691751072530673292166141936723932, -633233450173458506969111392533293074], [3963053413551210639299847047434860343679142, -8549859803982270431773700059315846628], [-4764761666283588566139020293147869912742538, 5116255698306113641176468275730749913], [1900464198860663363259676014216129665084466, 3019822216845629805924441428222120177], [-6159959297142447507183436764049615016034010, -2515486022682439443751184690819313948], [891572678538039977185969762627998217594062, 1527496257159715175536129790495818188], [200862328300108669150274009851402841056860, -1476118209100957669371042846160315176], [2618409086583642629878820981422192787766372, 3407219094064865341172543723041019950], [-8661820726753161248707666222115727477757698, 3148146715530479569155101968938968689], [11578399499977905714409027991974062446833232, 2813734401473421239493400023285662778], [-3986751748182042821395144046421945301798538, 2036554298189380650009701131726457103], [-7938427184950579433332204346238923145915010, -11189688468489320279753503293203370384], [1100563267396614192182467833410159107557822, 11422907983029611004833626184534125912], [-10518006375096601078719539895499189447935480, 1714889184381996556493242828596513672], [6506619450339571446147959606551047979577506, 2159016931064229887228892327106401761], [-855547602569531020153494427684090358622888, 12693619946094948538276073083362826298], [6610117072224789374292775116257259571459460, -13535133279681063629638001981486257484], [11179697307365781705682366137712384862727102, 2678618712198876788616165261646334959], [-1808634924725417020937246009369599526614634, 16484095842455324021720920525027700028], [-15425353195220237112421230530373936125087598, 2748277630600731991942530901199526560], [16057686511675155769995473162880343608017466, -957761087492612046895343510442156911], [-475792387019468540585195121324375392340610, 27563810116017435582779634745105781340], [-4785003458302748444734784560876219313073618, 20237338930684645147715529624245527856], [22828917197620330378693428159471899490642420, -3449641459297459758107386570958613704], [-3751321127314777106478344024507358318306178, -21104285898455637039336820199573182728], [-15136261961594650592465717074753630681919654, 2962541237667264577854265756405519443], [-17771324636372047740536479476038318907567474, 14581217229919661849937228928910465096], [5271743454156955295420046926651982165745366, -31342644252441229253372186726095538496], [8985333293306440917981529961754577229344822, -2017905721170408556097079348663721933], [-18555677066590504423018887737064430509537054, -22789016628218049701436227039602046373], [-25200076724206696288836059577870776937863290, 23531158517652254733716909575926945792], [16139391930220558518267755167330783208782582, 53045509626098448852731894061208344976], [-37261472516693942618951258545508366306310474, 9043558371568124734698440107164468092], [4437671578771393041301119971766033854910740, 13186382818678845964994295657393425736], [6226191998355180749398029833832081590761230, 44739057440128675969835641624963887616], [21962308259592046754246162188819462029085722, 32228049097750418874236170547732470992], [-29592785416006913658219436875746039793095618, 7305302318658861380561585210545501461], [-19500740488832833190397931514463428702916378, 57490772460453380044934373993958910952], [-12886309579903155701698759207848440243658778, 78458939985518622357810337261868049776], [-28396298829388487809949711565816623342111174, 64366514146597071538975068138385840527], [-54869061144890590871587870594306414958119658, -34549014901830593421363416686127670420], [359698780006569950615774419126957089116240, -50720151507629387785466503185133488240], [-49808234814239465199762316756895702046828554, 21196339764527463423409057421287334528], [-1004826322960098638144090496976738467754778, 84668631432190186089582152108333977167], [28263631727112234370544973532232407961357466, 57965851501599117966224973510979237427], [31069998148676673084012103213944007975209950, 90325417528938512223511117235988158056], [25826028715839622427533542646081104457336982, 47342490176788348731350222940460747372], [111050147490574624932716394711934386251347872, -60618982725128920223005630359407142250], [82408280768414421529490778081882273377822502, -2157216605910401294458115173932183061], [-28782683732837414788328434592664973299770908, -54764020291355796147850755237151884378], [49803682408222227714120636625807295364391626, 139715121454050592892416715475630640777], [-65226293383007828211087896562162499485358498, -46377194641815956344673784015476192448], [-141537363874711030711509686460617431379920814, 16424373305890502540318047028467940103], [21113332339969542140147812970958548976322692, 274840318671394700224233893564493714490], [-96997453988991117814596752056580023774358618, -77786708480071061851898712109036010684], [-182834642400187685288585229207979906624636554, -53163714700433781293506025912996843492], [-55452220557911804642279676932439051124004080, 145625107262157555632929646706376179060], [-232869203033036690219253072360243047816234730, -26877409719578490269880894439398295756], [249624729001754141549900210095326724611134922, -22276374258886992121967710090823176392], [62132398224966235322042236436672421382854786, -60459915038450287187410355701506654493], [155493537925073462787418771164012575225581662, 66665343546719259793667015405061893548], [267248660280960180421048677526520521197130272, -35093117634289948617382201412752839806], [121909858306924559944235763194685106389492622, 86738778931226729723541812605397727552], [-115483967921315785531426784634640887633954390, 153026310630895713765450445785663701224], [50275421645048301026550141174340236231762452, -414058984299242731508705402437319623190], [473941765016071184857947742717041408069289542, 86567379931252914265970661403369780080], [44083226756588075078773492611558009335989980, 274251347236027627972142590689568262664], [43651712367787807564916338829068948659839146, 406705098556032004521994210058127783039], [425581957738208586372185244054557224449002302, -120547097081383308354548909421302979936], [137732307484328936695839165626736806588147166, 71553759922098556939201799120238882088], [573410455224166330879853617261329070966060760, -103628570431931925071478091938625324876], [-30952888520255313895775352351426705400818858, 391702994362467128948999367715779942285], [73863111172048731106179089318787018503513072, -27306428662759944625352164958857164630], [-420193736767657355632138422878274703680530594, -311305349318050404902066423479978628924], [-211590497544847490029411414015239711730337814, -428898011146639537619816613700495637421], [268972426617806864658712354696752901118488190, -554840705949312814984210363068104464632], [99777321257978266689274793832428957349181320, 389615403580659733545521162249913828024], [200319422378530145433270550026329854767944662, -78467655953883568936115846580918678312], [-273792976241484807076032980094282451120722138, 512497755828575121279171444681650521963], [-399277204696130090936780676174696115043754570, -141069836170113127742447695617784971280], [-80277811234047882480829236225763207779413598, 1055689981970468891316018400058839924496], [-654247296915749159025870957011705872683051338, 170821396730407688866395762884765958053], [777875905042295883887823890465647982722434786, 135003442369403787077212809999868497885], [-646482419142955921619403323150273769154842790, 342157811785599512365684014257742905720], [295964371466177023502182363160033849109171300, -957737936750411503469674129510058275840], [-148103278873232734051033990401276335506909548, 402112423131175523212586572423507296722], [247592291995962993335897874680676456718929382, 432827815572599915799016927737970239896], [-153258591363100531550712262115552342437478730, -826311142773443083258274230107081682540], [-86883084473083995308568066813449225348995768, 1023282492025044038331604327325205727218], [-500568489029582373024988473418018532932091954, -791523792396370500114491201926432570256], [327143513398218427354730572242313401606114042, -1057748255842522678330700999165324789856], [-580617372950432412213925420681549735450171538, 1185283071350578872557042477374521896543], [-984050825613397885785789683691709156058972658, -200862083050402666395787332605280773160], [-509313949797250894214948994116829398780401858, 906267616557008170102837588264533902388], [-169334770736789271515215322633639368735979020, -1250787195548646447040734096427811886216], [289429926408181389045991561461622860979586542, -1710934662808969925895039065339267500995], [68464584138920160332049858578252346808221306, 1747994675799018628021094951241708085925], [-1910961090661814020837767883859140491272511858, -225987851207113736483379844640425997300], [-1393131839078632000751168465116846708531182358, 410835358665546697234728472141977413400], [91095921412844013790678045987998684589210206, -3172137819343534135916518617254583349152], [58549344815350904191958595647930214644432360, -1860472309176352305201374002018350068300], [-2526368740272575885642464444420237221032300418, 53474078449932079352599192553526808281], [-2136925502603303940917179737193060124847188128, -635226322800026261446909215276081567342], [3244780106414552008615102331836305070162387746, -265932468037244911604663187858825390633], [-1323648324667959155666775769444103018070871990, -1167515837178978021691664957822745072888], [61323914193626352394818833578862401127580582, 3220086704621552829862549826714253825216], [-2981496570441017360382790674550916642606353018, 767498489419912014940018634345636749628], [1909542129406121633340421886429704649531792146, 452468453529289867635466439366011678089], [1387958945475316860440463358330359576861887542, -19676890498551698189922867941480140960], [-2665599957201225182767293853716741417448674714, 703595817212566712716916775672909827616], [279594824734162988663058151588517687381723730, 1569081601131101226950656096367565161736], [-719382149980792926740826524818793378566691188, 4566245775396680045532946500831874249346], [-1357596000085143899160414241109823053554085418, 2467008975983283020714850302487729641176], [3558398816608590373650779371367650074595518900, 2413252976767048213945199144804983135096], [511386727215538026365781949386284622166744322, -5922908455463223378796065938345056549344], [-166203507542176825743955294820487461309623814, 2243376384847263643340088592739101511851], [1332662056159291350355234867581922001940760452, 2371558174538887933499127645950554700570], [2634948937877862151653777480856342542322335366, -4005770717580323188541813981933169110236], [-6108485547409426068572641258857812992255223968, -1346225296032851166571051660517425450594], [-5112318530275565098651027406910239843225756954, 2809707293536761294567232277239127376888], [-1139817027570718587397661257524330101310655638, 1961987705201175904670180963051721444320], [1085101146748530122038015909648350298819373422, -979663198987415996645300464100342142993], [-1313686020534852520889782089133210585777080970, -1654652775945619024448558045634505317312], [4866028411225214856713903724619905718750988862, 2792135116461999014426043880089683099828], [-1846252164367932919587015176837069127307035720, -5256815526445787156803200436097304093388], [-1005767332012251374536281425248222825757523528, 4908495749116010912354732440585670242030], [2927163263188950006121912637503008720991351566, 3842468348260724992023353109586471487140], [780184366909854950818753966149260057533040982, -7282013074507821011932118259472673383209], [-6395939612776358088062755353104349130806309554, 2345986589832799238216318894289999181004], [-20523902129179096506571276635660559116712998, -1690114724678288898223359375287977922592], [5372293743830262416227279846034205788850024666, 4592434941593725853487225044465342414133], [-5303157273880298753426960392333257660577212060, 2333447147236248460539463092443958891380], [-3185152601661440259095391403822754213651328974, 743783194245987310216423040992100897379], [1583199464633389279808506932658300401605092102, 840284145930461520630462019733481162964], [4895731499187447597674212486661770804351019526, 402985958353624024171960709634169617780], [-7960694507005114574572073106374634933632971298, 6916593971878314840855641429365584009939], [-273903552797043625623821460537601851734464378, 17801918853404368458121427985650411568452], [7933743175125447422360861900780595301176097152, -4847644328003712146411523507717527326754], [1372324671410729069278444435017739454026918940, 10987960716068803485965777048736199235912], [-9140135913007964784675055258506065224093967298, 5930522419887436975575787729269681251359], [8468667812737989764745286034827192808867930370, -10543729601229390859745801501644952255672], [5209263168621465665218907176154249806556499692, -7919861902952473283776151076685054913094], [-14402446554811976385166647658285182598730802794, 1212493501483837263087590153859923955500], [-8270897500263338050565886848278351998867132300, -4096808232564862346426372086117405373128], [9015007385470473155636562966076465953422917332, -4264088632312036594864510703624367344710], [-9093370150951804625116308135271489429140709778, -12418362075670821671227320501347781550208], [-11675730580394161012313320602743966459982174810, -285640795050194693413596987470892479900], [-8285349120496828251664037421043081843639067954, 274007515478247737564977346350210465032], [19399188184538768778576621764773894470212442102, -7557569164987085684643330497583472853536], [-6377403827502848599745834708580846831348380418, -19732149883325091130521001557078826424], [-20490245635669943368459222426821373959310681814, -4343274382376382214244562937892159510439], [-9370635416580774237915923318861815762023650514, 4079752624187344158969401958403949811152], [-8025689125357915778699751380818353215556020860, 11750485617291565984169037173560681249440], [-481242303785457278794302436802835015812318778, -5854845466906965928958669009780751750193], [-10138999018974070799326948156364870090638127428, 14278533068363582863191788888190200368662], [-13618146476852347129171891795250425984819149434, -6947155691630384646581044514522584712904], [-2557780177995318788533755404552851083410834018, 8554225746631345837719410834103401413461], [6530611656716580784074384970075399718268110106, -10622253418316363859269202000864913910907], [22244080586735305242949922766884602436792497910, -1425875805126246446395929768025669534220], [-5233747100490389827868212343705328296659884978, 2914796685207808904571574384442932255592], [11804837814550185911803261090970628122231202660, 11093478235797102726803712769210195101964], [9174597926697185018669092855947275773146978346, 28192739994403537114733539712358633048071], [2441284471006107363982779419187522090836593212, 17601851255380586769216266218508379718506], [-5499746596985993513950758675165204413199918338, -6670812267136064904155797638022879451712], [18463682873440998566402965849944153738721981880, 2768928643791180216532668927880745506540], [9248547773331337641680033933705719725013469130, 19980893676018957210501580469905759519104], [-26717161715635312330693581876213923875981505488, -8107885271196044847215135157069530632030], [6733638770101528811020279129730488764434241522, -17997718084529517367889281232587260851984], [14100676065708124510361986325166163119147400970, 1382112101912751793144635666824781814488], [11122996077257381238828947144893858416572087622, -9661184467331341764098953465736050899668], [4362281445915621047069484851609802740506054906, 1866132910444558736020151337933747069221], [-12525560985158634087693695436920384850200573634, 5669496541702864127093457434885317906496], [21798374344683888282276628200796873171276109730, 47517594219824378257754696739541004098528], [1007188024671844495394909750724400912490310092, -38676983759437335943845226847276899567206], [-5057289013948756654028706644444209040930114354, -51706958761027187619390622810612271790220], [32441474629848590048316076667847842351733182322, -23910570628146001318977170751522122460272], [-48344608901134639148164456540591008251044696658, 17552668473468998479521810708194226883545], [-14986473455875897132293523128882864621662903460, -60672656313280680075479440855640672271276], [-5109700673342663027040229596683639336712978098, -58148103139330184765779614207134635021576], [24364515252571824130326813810057285581007289446, -51654730488874898545041563620700796629336], [-26572528895754869982912100463517539211464392698, -45557758749068903258993047553541116796791], [-24305580063967449259386518341341364075025832688, -35408052231243718925565998831974577928786], [-15832368013284733033798351627679346412380865154, 41370930172054343772545760637576514256436], [29058630018716023110460258838741364530506323942, -52124774225076585217212507277328562547432], [-42824135763622207851208231940135890872824165280, 10559507825416492325878013497787181285320], [-60575292374238660586330924265649017510566497854, 1596760933438288441037336313034408885949], [14493105168336110844367548153896151182853798366, 64062925326195864228481217638969503811148], [55041732166987065270403867435660727628382780902, -49250583766229730038292240028298726847521], [-6139235732005722609284988716441279676843585030, 98175597388280183440015386898232171141392], [45496775270415355152726395502934398509123132086, 20734255080786649086733139933464572892828], [-26598464667267107989181514614891853294700629174, -33291652302041567571928126332984100890315], [-16325586800926423132909990223835368232004702140, -132535281743677507836510551698933968612740], [-4139714059241231125359767351354173860207634778, 92526113049629779704536273353540998333792], [19068151526991935534779525477867562503727319246, -101364598960664849294043052168360320621864], [-18435929432518459924322309221761967405270822698, -52088534911868564924363888319617097205971], [1051860490138160880369103679680068460256882190, 62321417900570991710741555516311605968204], [-41755039566101450310578752670721293913223088248, -13744700444927985126082215794724779995386], [-29518804707945866050425704601175722952824245640, -57407425222507747994779950754430018965016]]
